@@ -16,19 +16,6 @@
 *
 *********************************************/
 
-/**
-* space_to_nbsp()
-*
-* converts all spaces in the string to non-breaking spaces
-*
-* @param string $input string w/ spaces to have replaced
-*/
-function space_to_nbsp($input)
-{
-	return str_replace(" ", "&nbsp;", $input);
-} // end space_to_nbsp();
-
-
 /**
 * begin_page()
 *
@@ -39,141 +26,27 @@ function space_to_nbsp($input)
 * @param boolean $refresh    whether to refresh this page or not
 * @param string $bodytags    options for the <body> tag
 */
-function begin_page($pagename = "", $prettyname = "", $refresh = 0, $bodytags = "")
+function begin_page($pagename = "", $prettyname = "", $refresh = false, $bodytags = "", $javascript_files = array())
 {
 	// gather errors from prerequisits being met or not
 	$prereqs_errors = PrereqsMet();
+	$display_menu = false;
 	
-	echo '<?xml version="1.0" encoding="UTF-8"?>'."\n";
+	// always include these javascripts
+	array_push($javascript_files, "inputdefault.js");
+	
+	// always load this item
+	$bodytags .= ' onload="set_defaults(\'search\');"';
+	
+	// determine if we should display the menu or not
+	$display_menu = (IsLoggedIn() && !UpdaterNeedsRun() && count($prereqs_errors) == 0);
+	
+	DisplayPageHeader($pagename, $prettyname, $refresh, $display_menu, $bodytags, $javascript_files);
 ?>
-<!DOCTYPE html
-     PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
-     SYSTEM "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
 
-<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
-<head>
-	<title><?php
-	if (!empty($prettyname))
-	{
-		echo "$prettyname - ";
-	} // end if prettyname
-	echo $GLOBALS["netmrg"]["name"];
-	if (!empty($GLOBALS["netmrg"]["company"]))
-	{
-		echo " - {$GLOBALS['netmrg']['company']}";
-	} // end if company
-	?></title>
-	<link rel="stylesheet" type="text/css" href="<?php echo $GLOBALS["netmrg"]["webroot"]; ?>/include/netmrg.css">
-<?php if ($refresh) { ?>
-	<meta http-equiv="refresh" content="300">
-<?php } ?>
-</head>
-<body <?php echo($bodytags); ?>>
+<div id="content">
 <?php
-if (!empty($pagename))
-{
-?>
-<!-- <?php echo $pagename; ?> -->
-<?php
-} // end if there's a pagename, output it
-?>
-<table class="titletable" cellspacing="0" cellpadding="0" border="0" width="100%">
-<tr>
-	<td class="logo" rowspan="2" width="35">
-		<img src="<?php echo get_image_by_name("logo"); ?>" alt="logo" border="0">
-	</td>
-	<td class="title_name" rowspan="2" width="100%">
-		<a href="<?php echo $GLOBALS["netmrg"]["webhost"].$GLOBALS["netmrg"]["webroot"]; ?>" class="title_name">
-		<?php echo $GLOBALS["netmrg"]["name"]; ?>
-		</a>
-	</td>
-	<td class="company" align="right" valign="top">
-		<a class="company" href="<?php echo $GLOBALS["netmrg"]["companylink"]; ?>">
-		<?php echo(space_to_nbsp($GLOBALS["netmrg"]["company"])); ?>
-		</a>
-	</td>
-</tr>
-<tr>
-	<td class="logindata" align="left" valign="bottom">
-	<?php
-		if (IsLoggedIn())
-		{
-			echo '<span class="loggedintext">Logged&nbsp;in&nbsp;as&nbsp;</span>';
-			echo '<span class="loggedinuser">';
-			echo(space_to_nbsp($_SESSION["netmrgsess"]["prettyname"]));
-			echo "</span>\n";
-		}
-		else
-		{
-			echo '<span class="loggedouttext">Not&nbsp;Logged&nbsp;In</span>'."\n";
-		} // end if logged in or not
-	?>
-	</td>
-</tr>
-</table>
-<?php // needs some kind of spacing for IE.  A <br> is too much.
-?>
-<table cellspacing="0" cellpadding="0" border="0" width="100%">
-<tr>
-	<td class="empty" valign="top"><img src="<?php echo $GLOBALS["netmrg"]["webroot"]; ?>/img/trans.gif" width="4" height="1" alt="trans gif"></td>
-	<td valign="top">
-	<?php
-		if (IsLoggedIn() && !UpdaterNeedsRun() && count($prereqs_errors) == 0)
-		{
-			display_menu();
-		} // end if is logged in, show the menu
-	?>
-	<img src="<?php echo $GLOBALS["netmrg"]["webroot"]; ?>/img/trans.gif" width="125" height="1" alt="trans gif">
-	</td>
-	<td class="empty" valign="top"><img src="<?php echo $GLOBALS["netmrg"]["webroot"]; ?>/img/trans.gif" width="4" height="1" alt="trans gif"></td>
-	<td valign="top" width="100%">
-
-<?php
-	// if we need to run the updater, don't do anything else
-	if (IsLoggedIn() && (UpdaterNeedsRun() || count($prereqs_errors)))
-	{
-		if (UpdaterNeedsRun())
-		{
-			if (strpos($_SERVER["PHP_SELF"], "updater.php") !== false)
-			{
-				echo "<!-- updater needs run -->\n";
-				if ($_SESSION["netmrgsess"]["permit"] != 3)
-				{
-?>
-<!-- updater needs run and on updater page -->
-This installation is currently unusable due to a recent upgrade.  Please contact 
-your administrator to have the rest of the upgrade performed. <br />
-<a href="logout.php">logout</a><br />
-<?php
-					end_page();
-					exit();
-				} // end if not admin
-			}
-			else
-			{
-?>
-<!-- updater needs run and not on updater page -->
-Your installation is currently in an unusable state; please proceed to update 
-your installation <a href="updater.php">here</a><br />
-<a href="logout.php">logout</a><br />
-<?php
-				end_page();
-				exit();
-			} // end if updater needs run
-		} // end if updater needs run
-		
-		else if (count($prereqs_errors))
-		{
-			echo "<!-- prereqs not met -->\n";
-			foreach ($prereqs_errors as $error)
-			{
-				echo '<span style="color: red;">'.$error.'</span><br />'."\n";
-			} // end foreach prereq error
-			
-			end_page();
-			exit();
-		} // end if prereqs weren't met
-	} // end if logged in and updater needs run or prereqs weren't met
+	CheckInstallState($prereqs_errors);
 } // end begin_page()
 
 
@@ -186,9 +59,15 @@ your installation <a href="updater.php">here</a><br />
 function end_page() 
 {
 ?>
-	</td>
-</tr>
-</table>
+</div> <!-- end #content -->
+
+<div id="footer">
+	<a href="http://www.netmrg.net/">
+	<img src="<?php echo get_image_by_name("logo"); ?>" alt="logo" />
+	NetMRG
+	</a>
+	<a href="about.php">&copy; 2003-2006</a>
+</div> <!-- end #footer -->
 
 </body>
 </html>
@@ -196,6 +75,122 @@ function end_page()
 } // end end_page()
 
 
+/**
+* DisplayPageHeader()
+*
+* draws the top of the page
+*
+* @param string $pagename       page that this is
+* @param string $prettyname     shown in the title bar
+* @param boolean $display_menu  whether to refresh this page or not
+* @param boolean $refresh       whether to refresh this page or not
+* @param string $bodytags       options for the <body> tag
+*/
+function DisplayPageHeader($pagename = "", $prettyname = "", $refresh = false, $display_menu = false, $bodytags = "", $javascript_files = array())
+{
+	echo '<?xml version="1.0" encoding="UTF-8"?>'."\n";
+?>
+<!DOCTYPE html 
+	PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
+	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
+
+<head>
+	<title><?php print GetPageTitle($prettyname); ?></title>
+	
+	<link rel="stylesheet" type="text/css" href="<?php echo $GLOBALS["netmrg"]["webroot"]; ?>/include/netmrg.css" />
+	
+<?php
+	if (count($javascript_files) > 0)
+	{
+		foreach ($javascript_files as $jsfile)
+		{
+			echo '	<script language="javascript" type="text/javascript" src="'.$GLOBALS["netmrg"]["webroot"].'/include/'.$jsfile.'"></script>'."\n";
+		} // end foreach jsfile
+	} // end if we have javascript to load
+?>
+	
+<?php if ($refresh) { ?>
+	<meta http-equiv="refresh" content="300" />
+<?php } ?>
+</head>
+
+<body <?php echo($bodytags); ?>>
+<?php if (!empty($pagename)) { ?>
+<!-- <?php echo $pagename; ?> -->
+<?php } // end if there's a pagename, output it ?>
+
+<div id="header">
+	<div id="headerinfo">
+		<div id="logindata">
+			<?php echo GetLoginInfo(); ?>
+		</div>
+		<div id="search">
+<?php if (IsLoggedIn()) { ?>
+			<form name="searchform" action="search.php" method="GET">
+				<input type="text" name="query" default="[search]" size="15" />
+			</form>
+<?php } // end if logged in ?>
+		</div>
+	</div> <!-- end #headerinfo -->
+	<div id="company">
+		<a href="<?php echo $GLOBALS["netmrg"]["companylink"]; ?>">
+		<?php echo(space_to_nbsp($GLOBALS["netmrg"]["company"])); ?>
+		</a>
+	</div>
+<?php
+	// display menu or not
+	if ($display_menu)
+	{
+		DisplayTopMenu();
+	} // end if display the menu
+?>
+</div> <!-- end #header -->
+
+<?php
+} // end DisplayPageHeader();
+
+
+/**
+* DisplayTopMenu();
+*
+* Displays a menu bar along the top of the page
+*/
+function DisplayTopMenu()
+{
+	global $LOCAL_MENU, $LOCAL_MENU_CURTREE, $LOCAL_MENU_CURITEM;
+	
+	CreateLocalMenu();
+	
+	echo '<div id="topmenu">'."\n";
+	echo "	<ul>\n";
+	while (list($menuname, $menuitems) = each($LOCAL_MENU))
+	{
+		echo '		<li><a '. ($menuname == $LOCAL_MENU_CURTREE ? 'class="navcurrent" ' : '') .'href="'. $menuitems[0]["link"] .'">';
+		echo $menuname;
+		echo "</a></li>\n";
+	} // end while we still have menu items
+	echo "	</ul>\n\n";
+	echo "	&nbsp;\n";
+	echo '	<div style="clear: left;"></div>'."\n";
+	echo "</div> <!-- end #topmenu -->\n\n";
+	
+	echo '<div id="secondmenu">'."\n";
+	echo "	<ul>\n";
+	foreach ($LOCAL_MENU[$LOCAL_MENU_CURTREE] as $menuitem)
+	{
+		echo '		<li><a '. ($LOCAL_MENU_CURITEM == $menuitem['link'] ? 'class="navcurrent" ' : '') .'title="'. $menuitem["descr"] .'" href="'. $menuitem["link"] .'">';
+		echo $menuitem["name"];
+		echo "</a></li>\n";
+	} // end while we still have menu items
+	echo "	</ul>\n\n";
+	echo "	&nbsp;\n";
+	echo '	<div style="clear: left;"></div>'."\n";
+	echo "</div> <!-- end #secondmenu -->\n\n";
+} // end DisplayTopMenu();
+
+
 /**
 * PrepGroupNavHistory($type, $id)
 *
@@ -311,57 +306,57 @@ function DrawGroupNavHistory($type, $id)
 		{
 			case "event" : 
 				$t = ' : ';
-				if ($type != "event") $t .= '<a href="responses.php?event_id='.$breadcrumb["id"].'&tripid='.$_REQUEST["tripid"].'">';
+				$t .= '<a href="responses.php?event_id='.$breadcrumb["id"].'&tripid='.$_REQUEST["tripid"].'">';
 				$t .= get_event_name($breadcrumb["id"]);
-				if ($type != "event") $t .= "</a>\n";
+				$t .= "</a>\n";
 				print $t;
 				break;
 				
 			case "monitor" :
 				$t = ' : ';
-				if ($type != "monitor") $t .= '<a href="events.php?mon_id='.$breadcrumb["id"].'&tripid='.$_REQUEST["tripid"].'">';
+				$t .= '<a href="events.php?mon_id='.$breadcrumb["id"].'&tripid='.$_REQUEST["tripid"].'">';
 				$t .= get_short_monitor_name($breadcrumb["id"]);
-				if ($type != "monitor") $t .= "</a>\n";
+				$t .= "</a>\n";
 				print $t;
 				break;
 				
 			case "int_snmp_cache_view" :
 				$t = ' : ';
-				if ($type != "int_snmp_cache_view") $t .= '<a href="snmp_cache_view.php?dev_id='.$breadcrumb["id"].'&action=view&type=interface'.'&tripid='.$_REQUEST["tripid"].'">';
+				$t .= '<a href="snmp_cache_view.php?dev_id='.$breadcrumb["id"].'&action=view&type=interface'.'&tripid='.$_REQUEST["tripid"].'">';
 				$t .= "interface cache";
-				if ($type != "int_snmp_cache_view") $t .= "</a>\n";
+				$t .= "</a>\n";
 				print $t;
 				break;
 				
 			case "disk_snmp_cache_view" :
 				$t = ' : ';
-				if ($type != "disk_snmp_cache_view") $t .= '<a href="snmp_cache_view.php?dev_id='.$breadcrumb["id"].'&action=view&type=disk'.'&tripid='.$_REQUEST["tripid"].'">';
+				$t .= '<a href="snmp_cache_view.php?dev_id='.$breadcrumb["id"].'&action=view&type=disk'.'&tripid='.$_REQUEST["tripid"].'">';
 				$t .= "disk cache";
-				if ($type != "disk_snmp_cache_view") $t .= "</a>\n";
+				$t .= "</a>\n";
 				print $t;
 				break;
 				
 			case "sub_device" :
 				$t = ' : ';
-				if ($type != "sub_device") $t .= '<a href="monitors.php?sub_dev_id='.$breadcrumb["id"].'&tripid='.$_REQUEST["tripid"].'">';
+				$t .= '<a href="monitors.php?sub_dev_id='.$breadcrumb["id"].'&tripid='.$_REQUEST["tripid"].'">';
 				$t .= get_sub_device_name($breadcrumb["id"]);
-				if ($type != "sub_device") $t .= "</a>\n";
+				$t .= "</a>\n";
 				print $t;
 				break;
 				
 			case "device" :
 				$t = ' : ';
-				if ($type != "device") $t .= '<a href="sub_devices.php?dev_id='.$breadcrumb["id"].'&tripid='.$_REQUEST["tripid"].'">';
+				$t .= '<a href="sub_devices.php?dev_id='.$breadcrumb["id"].'&tripid='.$_REQUEST["tripid"].'">';
 				$t .= get_device_name($breadcrumb["id"]);
-				if ($type != "device") $t .= "</a>\n";
+				$t .= "</a>\n";
 				print $t;
 				break;
 				
 			case "group" :
 				$t = ' : ';
-				if ($type != "group" || ($type == "group" && $id != $breadcrumb["id"])) $t .= '<a href="grpdev_list.php?parent_id='.$breadcrumb["id"].'&tripid='.$_REQUEST["tripid"].'">';
+				$t .= '<a href="grpdev_list.php?parent_id='.$breadcrumb["id"].'&tripid='.$_REQUEST["tripid"].'">';
 				$t .= ($breadcrumb["id"] == 0) ? "All Groups" : get_group_name($breadcrumb["id"]);
-				if ($type != "group" || ($type == "group" && $id != $breadcrumb["id"])) $t .= "</a>\n";
+				$t .= "</a>\n";
 				print $t;
 				break;
 		} // end switch type
@@ -374,6 +369,180 @@ function DrawGroupNavHistory($type, $id)
 } // end DrawGroupNavHistory();
 
 
+/**
+* GetPageTitle()
+*
+* returns the title for a page
+*/
+function GetPageTitle($prettyname = "")
+{
+	$pagetitle = "";
+	
+	if (!empty($prettyname))
+	{
+		$pagetitle .= "$prettyname - ";
+	} // end if prettyname
+	
+	$pagetitle .= $GLOBALS["netmrg"]["name"];
+	
+	if (!empty($GLOBALS["netmrg"]["company"]))
+	{
+		$pagetitle .= " - {$GLOBALS['netmrg']['company']}";
+	} // end if company
+	
+	return $pagetitle;
+} // end GetPageTitle();
+
+
+/**
+* GetLoginInfo()
+*
+* returns the login information for the page header
+*/
+function GetLoginInfo()
+{
+	$logintext = "";
+	
+	if (IsLoggedIn())
+	{
+		$logintext .= '<span class="loggedintext">Logged&nbsp;in&nbsp;as&nbsp;</span>';
+		$logintext .= '<span class="loggedinuser">';
+		$logintext .= space_to_nbsp($_SESSION["netmrgsess"]["prettyname"]);
+		$logintext .= "</span>\n";
+	}
+	else
+	{
+		$logintext .= '<span class="loggedouttext">Not&nbsp;Logged&nbsp;In</span>'."\n";
+	} // end if logged in or not
+	
+	return $logintext;
+} // end GetLoginInfo();
+
+
+/**
+* CheckInstallState()
+*
+* checks things like whether the updater needs run and the 
+* prerequisites are met before allowing you to view the rest
+* of the webpage
+* 
+* @param array array of errors returned by prerequisite checks
+*/
+function CheckInstallState($prereqs_errors = array())
+{
+	global $PERMIT;
+	
+	// if we need to run the updater, don't do anything else
+	if (IsLoggedIn() && (UpdaterNeedsRun() || count($prereqs_errors)))
+	{
+		if (UpdaterNeedsRun())
+		{
+			if (strpos($_SERVER["PHP_SELF"], "updater.php") !== false)
+			{
+				echo "<!-- updater needs run -->\n";
+				if ($_SESSION["netmrgsess"]["permit"] != $PERMIT['Admin'])
+				{
+?>
+<!-- updater needs run and on updater page -->
+This installation is currently unusable due to a recent upgrade.  Please contact 
+your administrator to have the rest of the upgrade performed. <br />
+<a href="logout.php">logout</a><br />
+<?php
+					end_page();
+					exit();
+				} // end if not admin
+			} // end if we're at the updater
+			else
+			{
+?>
+<!-- updater needs run and not on updater page -->
+Your installation is currently in an unusable state; please proceed to update 
+your installation <a href="updater.php">here</a><br />
+<a href="logout.php">logout</a><br />
+<?php
+				end_page();
+				exit();
+			} // end if we're not on the updater page
+		} // end if updater needs run
+		
+		else if (count($prereqs_errors))
+		{
+			echo "<!-- prereqs not met -->\n";
+			foreach ($prereqs_errors as $error)
+			{
+				echo '<span style="color: red;">'.$error.'</span><br />'."\n";
+			} // end foreach prereq error
+			
+			end_page();
+			exit();
+		} // end if prereqs weren't met
+	} // end if logged in and updater needs run or prereqs weren't met
+} // end CheckInstallState();
+
+
+/**
+* MakeNavURI($name, $link, $title, $onclick, $alias=array());
+*
+* makes a navigation uri link and will include #navcurrent id
+* if $link or items in $alias are equal to $_SERVER["SCRIPT_URL"]
+*/
+function MakeNavURI($name, $link, $title = "", $onclick = "", $alias=array())
+{
+	$currentid = "";
+	$a_title = "";
+	$a_onclick = "";
+	
+	array_push($alias, $link);
+	if (in_array(basename($_SERVER["SCRIPT_NAME"]), $alias))
+	{
+		$currentid = ' class="navcurrent"';
+	} // end if we're at the current page
+	
+	if (!empty($title))
+	{
+		$a_title = ' title="'.htmlentities($title).'"';
+	} // end if a title exists
+	
+	if (!empty($onclick))
+	{
+		$a_onclick = ' onclick="'.addslashes($onclick).'"';
+	} // end if a title exists
+	
+	return '<a'.$currentid.$a_title.$a_onclick.' href="'.htmlentities($link).'">'.$name.'</a>';
+} // end MakeNavURI();
+
+
+/**
+* space_to_nbsp()
+*
+* converts all spaces in the string to non-breaking spaces
+*
+* @param string $input string w/ spaces to have replaced
+*/
+function space_to_nbsp($input)
+{
+	return str_replace(" ", "&nbsp;", $input);
+} // end space_to_nbsp();
+
+
+/**
+* GetClassList($class_array)
+*
+* returns a string with the class items passed in $class_array()
+*/
+function GetClassList($class_array = array())
+{
+	$class_list = "";
+	
+	if (count($class_array) > 0)
+	{
+		$class_list = ' class="'.implode(' ', $class_array).'"';
+	} // end if class items
+	
+	return $class_list;
+} // end GetClassList();
+
+
 
 /*********************************************
 *
@@ -800,13 +969,13 @@ function make_edit_select_option($name, $value, $selected)
 	if ($selected)
 	{
 ?>
-		<option value="<?php print($value); ?>" SELECTED><?php print($name); ?></option>
+		<option value="<?php print($value); ?>" SELECTED><?php print(htmlspecialchars($name)); ?></option>
 <?php
 	}
 	else
 	{
 ?>
-		<option value="<?php print($value); ?>"><?php print($name); ?></option>
+		<option value="<?php print($value); ?>"><?php print(htmlspecialchars($name)); ?></option>
 <?php
 	} // end else
 } // end make_edit_select_option
@@ -821,7 +990,7 @@ function make_edit_text($header, $name, $size, $maxlength, $value)
 
 	<b><?php print($header) ?></b><br />
 
-	<input type="text" name="<?php print($name) ?>" size="<?php print($size) ?>" maxlength="<?php print($maxlength) ?>" value="<?php print($value); ?>"><br><br>
+	<input type="text" name="<?php print($name) ?>" size="<?php print($size) ?>" maxlength="<?php print($maxlength) ?>" value="<?php print(htmlspecialchars($value)); ?>"><br><br>
 
 	</td></tr>
 
@@ -838,7 +1007,7 @@ function make_edit_textarea($header, $name, $rows, $columns, $value)
 
 	<b><?php print($header) ?></b><br />
 
-	<textarea name="<?php print($name) ?>" rows="<?php print($rows) ?>" cols="<?php print($columns) ?>"><?php print($value); ?></textarea><br><br>
+	<textarea name="<?php print($name) ?>" rows="<?php print($rows) ?>" cols="<?php print($columns) ?>"><?php print(htmlspecialchars($value)); ?></textarea><br><br>
 
 	</td></tr>
 
@@ -855,7 +1024,7 @@ function make_edit_color($header, $name, $value)
 
 	<?php print('<b>' . $header . '</b><br />'); ?>
 
-	<input id="<?php print($name); ?>field" type="text" name="<?php print($name) ?>" size="10" maxlength="7" value="<?php print($value); ?>">
+	<input id="<?php print($name); ?>field" type="text" name="<?php print($name) ?>" size="10" maxlength="7" value="<?php print(htmlspecialchars($value)); ?>">
 
         <input type="button" name="<?php print($name . 'cbtn'); ?>" value="Choose" onClick="colorDialog('<?php print($name); ?>')">
 	<br /><br />
@@ -877,7 +1046,7 @@ function make_edit_password($header, $name, $size, $maxlength, $value, $options
 
 	<b><?php print($header) ?></b><br>
 
-	<input type="password" name="<?php print($name) ?>" size="<?php print($size) ?>" maxlength="<?php print($maxlength) ?>" value="<?php print($value); ?>"><br><br>
+	<input type="password" name="<?php print($name) ?>" size="<?php print($size) ?>" maxlength="<?php print($maxlength) ?>" value="<?php print(htmlspecialchars($value)); ?>"><br><br>
 
 	</td></tr>
 
@@ -891,7 +1060,7 @@ function make_edit_hidden($name, $value)
 	// Creates a form hidden text control
 	?>
 
-	<input type="hidden" name="<?php print($name) ?>" value="<?php print($value); ?>">
+	<input type="hidden" name="<?php print($name) ?>" value="<?php print(htmlspecialchars($value)); ?>">
 
 	<?php
 
@@ -995,11 +1164,11 @@ function make_edit_select_monitor($mon_id_cur, $prepended_array = array())
 
 } // end make_edit_select_monitor
 
-function make_edit_select_subdevice($subdev_id_cur, $prepended_array = array())
+function make_edit_select_subdevice($subdev_id_cur, $prepended_array = array(), $select_options = "")
 {
 	// Creates an edit select box for the selection of "subdevices"
 
-	make_edit_select("Subdevice:", "subdev_id");
+	make_edit_select("Subdevice:", "subdev_id[]", $select_options);
 
 	// loop through things to put @ the end of the select box
 	while (list($key, $value) = each($prepended_array))
