@@ -143,7 +143,7 @@ function rrd_legend_escape($string)
 {
 	if ($string == "") return "";
 	$string = str_replace(":", "\:", $string);
-	return (":\"" . $string . "\"");
+	return (":" . escapeshellarg($string));
 }
 
 function get_microtime()
@@ -343,6 +343,16 @@ function apply_template($subdev_id, $template_id)
 	}
 
 	db_update("INSERT INTO view SET object_id={$sd_row['dev_id']}, object_type='device', graph_id=$template_id, type='template', pos={$pos_row['newpos']}, subdev_id=$subdev_id");
+	
+	// add templated graph to the sub-device's view
+	$q = db_query("SELECT max(pos)+1 AS newpos FROM view WHERE object_type='subdevice' AND object_id=$subdev_id");
+	$pos_row = db_fetch_array($q);
+	if (!isset($pos_row['newpos']) || empty($pos_row['newpos']))
+	{
+		$pos_row['newpos'] = 1;
+	}
+
+	db_update("INSERT INTO view SET object_id=$subdev_id, object_type='subdevice', graph_id=$template_id, type='template', pos={$pos_row['newpos']}, subdev_id=$subdev_id");
 
 }  // apply_template()
 
@@ -529,122 +539,100 @@ function GetGroupParents($group_id)
 
 
 /**
-* GetDeviceGroups($device_id);
+* GetGroups($type,$id);
 *
-* returns the groups that this device is in as an array
+* returns an array of groups that this $type is in
 *
 */
-function GetDeviceGroups($device_id)
+function GetGroups($type,$id)
 {
-	$db_result = db_query("
-		SELECT groups.id AS group_id 
-		FROM groups, dev_parents, devices
-		WHERE devices.id = '$device_id' 
-		AND devices.id = dev_parents.dev_id
-		AND dev_parents.grp_id = groups.id
-		GROUP BY group_id");
-
 	$group_arr = array();
-	while ($r = mysql_fetch_array($db_result))
+	switch ($type)
 	{
-		array_push($group_arr, $r["group_id"]);
-		$group_arr = array_merge($group_arr, GetGroupParents($r["group_id"]));
-	} // end while we have results
+		case "group":
+			$query = array("SELECT '$id' as group_id");
+			break;
+		case "device":
+			$query = array("
+				SELECT groups.id AS group_id 
+				FROM groups, dev_parents, devices
+				WHERE devices.id = '$id' 
+				AND devices.id = dev_parents.dev_id
+				AND dev_parents.grp_id = groups.id
+				GROUP BY group_id");
+			break;
+		case "subdevice":
+			$query = array("
+				SELECT groups.id AS group_id 
+				FROM groups, dev_parents, devices, sub_devices 
+				WHERE sub_devices.id = '$id' 
+				AND sub_devices.dev_id = devices.id
+				AND devices.id = dev_parents.dev_id
+				AND dev_parents.grp_id = groups.id
+				GROUP BY group_id",
+				"
+				SELECT object_id AS group_id
+				FROM view
+				WHERE object_type='group'
+				AND subdev_id = '$id'
+				GROUP BY group_id"
+				);
+			break;
+		case "monitor":
+			$query = array("
+				SELECT groups.id AS group_id
+				FROM groups, dev_parents, devices, sub_devices, monitors
+				WHERE monitors.id = '$id'
+				AND sub_devices.id = monitors.sub_dev_id
+				AND sub_devices.dev_id = devices.id
+				AND devices.id = dev_parents.dev_id
+				AND dev_parents.grp_id = groups.id
+				GROUP BY group_id");
+			break;
+		case "customgraph":
+			$query = array("
+				SELECT object_id, object_type
+				FROM view
+				WHERE type = 'graph'
+				AND graph_id = '$id'");
+			break;
+		default:
+			// an unknown type should have no groups
+			return $group_arr;
+	} // end switch($type)
+	
+	foreach ($query as $sql_cmd)
+	{
+		$db_result = db_query($sql_cmd);
+		while ($r = mysql_fetch_array($db_result))
+		{
+			if ($type == "customgraph")
+			{
+				$group_arr = array_merge($group_arr, GetGroups($r["object_type"],$r["object_id"]));
+			}
+			else
+			{
+				array_push($group_arr, $r["group_id"]);
+				$group_arr = array_merge($group_arr, GetGroupParents($r["group_id"]));
+			}
+		} // end while we have results
+	}
 	
 	return $group_arr;
-} // end GetDeviceGroups();
+} // end GetGroups();
 
 
 /**
-* GetSubdeviceGroups($subdevice_id);
+* GetSubdeviceParent($subdevice_id);
 *
-* returns the groups that this subdevice is in as an array
+* returns the parent device of the $subdevice_id
 *
+* @param integer subdevice_id
 */
-function GetSubdeviceGroups($subdevice_id)
+function GetSubdeviceParent($subdevice_id)
 {
-	$db_result = db_query("
-		SELECT groups.id AS group_id 
-		FROM groups, dev_parents, devices, sub_devices 
-		WHERE sub_devices.id = '$subdevice_id' 
-		AND sub_devices.dev_id = devices.id
-		AND devices.id = dev_parents.dev_id
-		AND dev_parents.grp_id = groups.id
-		GROUP BY group_id");
-
-	$group_arr = array();
-	while ($r = mysql_fetch_array($db_result))
-	{
-		array_push($group_arr, $r["group_id"]);
-		$group_arr = array_merge($group_arr, GetGroupParents($r["group_id"]));
-	} // end while we have results
-	
-	return $group_arr;
-} // end GetSubdeviceGroups();
-
-
-/**
-* GetMonitorGroups($monitor_id);
-*
-* returns the groups that this monitor is in as an array
-*
-*/
-function GetMonitorGroups($monitor_id)
-{
-	$db_result = db_query("
-		SELECT groups.id AS group_id
-		FROM groups, dev_parents, devices, sub_devices, monitors
-		WHERE monitors.id = '$monitor_id'
-		AND sub_devices.id = monitors.sub_dev_id
-		AND sub_devices.dev_id = devices.id
-		AND devices.id = dev_parents.dev_id
-		AND dev_parents.grp_id = groups.id
-		GROUP BY group_id");
-
-	$group_arr = array();
-	while ($r = mysql_fetch_array($db_result))
-	{
-		array_push($group_arr, $r["group_id"]);
-		$group_arr = array_merge($group_arr, GetGroupParents($r["group_id"]));
-	} // end while we have results
-	
-	return $group_arr;
-} // end GetMonitorGroups();
-
-
-/**
-* GetCustomGraphGroups($customgraph_id);
-*
-* returns the groups that this custom graph is in as an array
-*
-*/
-function GetCustomGraphGroups($customgraph_id)
-{
-	$db_result = db_query("
-		SELECT object_id, object_type
-		FROM view
-		WHERE type = 'graph'
-		AND graph_id = '$customgraph_id'");
-	
-	$group_arr = array();
-	while ($r = mysql_fetch_array($db_result))
-	{
-		if ($r["object_type"] == "group")
-		{
-			array_push($group_arr, $r["object_id"]);
-		} // end if group id, push it on
-		else if ($r["object_type"] == "device")
-		{
-			$group_arr = array_merge($group_arr, GetDeviceGroups($r["object_id"]));
-		} // end if device id, get groups
-		else if ($r["object_type"] == "subdevice")
-		{
-			$group_arr = array_merge($group_arr, GetSubdeviceGroups($r["object_id"]));
-		} // end if subdevice id, get groups
-	} // end while we have results
-	
-	return $group_arr;
-} // end GetCustomGraphGroups();
+	return db_fetch_cell("SELECT dev_id FROM sub_devices WHERE id = '$subdevice_id'");
+} // end GetSubdeviceParent();
 
 
 /**
@@ -668,17 +656,17 @@ function duplicate_device($dev_id)
 	db_query("CREATE TEMPORARY TABLE tmpdev 
 		SELECT id, name, ip, snmp_read_community, dev_type, snmp_recache_method, 
 			disabled, snmp_avoided, snmp_uptime, snmp_ifnumber, snmp_version, snmp_timeout, 
-			snmp_retries, snmp_port 
+			snmp_retries, snmp_port, no_snmp_uptime_check
 			FROM devices
 			WHERE id='$dev_id'");
 	db_query("
 		INSERT INTO devices
 		(name, ip, snmp_read_community, dev_type, snmp_recache_method, disabled,  
 			snmp_avoided, snmp_uptime, snmp_ifnumber, snmp_version, snmp_timeout, 
-			snmp_retries, snmp_port)
+			snmp_retries, snmp_port, no_snmp_uptime_check)
 		SELECT concat(name, ' (duplicate)'), ip, snmp_read_community, dev_type, snmp_recache_method, 
 			disabled, snmp_avoided, snmp_uptime, snmp_ifnumber, snmp_version, snmp_timeout, 
-			snmp_retries, snmp_port 
+			snmp_retries, snmp_port, no_snmp_uptime_check 
 			FROM tmpdev
 			WHERE id='$dev_id'");
 	$new_dev_id = db_insert_id();
@@ -914,6 +902,30 @@ function delete_view_item($item_id)
 		AND pos > " . $pos);
 }
 
+function is_view_item_extreme($object_id, $object_type, $item_id, $which)
+{
+	$query = db_query("
+	SELECT 	id, pos
+	FROM 	view
+	WHERE 	object_id=$object_id
+	AND 	object_type='$object_type'
+	ORDER BY pos $which");
+
+	$row = db_fetch_array($query);
+
+	return ($row['id'] == $item_id);
+}
+
+function is_view_item_top($object_id, $object_type, $item_id)
+{
+	return is_view_item_extreme($object_id, $object_type, $item_id, "ASC");
+}
+
+function is_view_item_bottom($object_id, $object_type, $item_id)
+{
+	return is_view_item_extreme($object_id, $object_type, $item_id, "DESC");
+}
+
 function move_view_item($object_id, $object_type, $item_id, $direction)
 {
 	//echo ("$object_id, $object_type, $item_id, $direction");
@@ -953,6 +965,19 @@ function move_view_item($object_id, $object_type, $item_id, $direction)
 		}
 	}
 }
+
+function move_view_item_top($object_id, $object_type, $item_id)
+{
+	while (!is_view_item_top($object_id, $object_type, $item_id))
+		move_view_item($object_id, $object_type, $item_id, "up");
+}
+
+function move_view_item_bottom($object_id, $object_type, $item_id)
+{
+	while (!is_view_item_bottom($object_id, $object_type, $item_id))
+		move_view_item($object_id, $object_type, $item_id, "down");
+}
+
 // Recursive Deletion Section (for orphan prevention if nothing else)
 
 function delete_group($group_id)
@@ -1048,6 +1073,14 @@ function delete_subdevice($subdev_id)
 	{
 		delete_monitor($monitor_row["id"]);
 	}
+
+	$view_handle = db_query("SELECT id FROM view WHERE type='template' AND subdev_id=$subdev_id");
+	
+	while ($view_row = db_fetch_array($view_handle))
+	{
+		delete_view_item($view_row['id']);
+	}
+
 } // end delete_subdevice();
 
 
@@ -1162,6 +1195,44 @@ function addslashes_deep($value)
 } // end addslashes_deep();
 
 
+/**
+* CreateLocalMenu():
+*
+* creates a local version of the menu w/ only the user's authorized items
+*/
+function CreateLocalMenu()
+{
+	global $MENU, $LOCAL_MENU, $LOCAL_MENU_CURTREE, $LOCAL_MENU_CURITEM;
+	
+	while (list($menuname, $menuitems) = each($MENU))
+	{
+		// foreach menu item
+		$authorized_subitems = array();
+		foreach ($menuitems as $menuitem)
+		{
+			if (basename($_SERVER["SCRIPT_NAME"]) == $menuitem["link"])
+			{
+				$LOCAL_MENU_CURTREE = $menuname;
+				$LOCAL_MENU_CURITEM = $menuitem["link"];
+			} // end if we're in this group, display its menu items
+			
+			if ($_SESSION["netmrgsess"]["permit"] >= $menuitem["authLevelRequired"]
+				&& $menuitem["display"] !== false)
+			{
+				array_push($authorized_subitems, $menuitem);
+			} // end if we have enough permissions to view this subitem
+		} // end foreach menu item
+		
+		// if we had some item output (ie, we had auth to view at least ONE item in this submenu)
+		// and we're under this current menu heading
+		if (count($authorized_subitems))
+		{
+			$LOCAL_MENU[$menuname] = $authorized_subitems;
+		} // end if item output wasn't empty
+	} // end while we still have menu items
+} // end CreateLocalMenu();
+
+
 /**
 * GetUserPref($module, $pref)
 *
@@ -1286,6 +1357,11 @@ function GetXMLConfig()
 	$GLOBALS["netmrg"]["rrdtool"]     = $xmlconfig["NETMRG"][0]["PATHS"][0]["RRDTOOL"][0]["VALUE"];
 	$GLOBALS["netmrg"]["rrdroot"]     = $xmlconfig["NETMRG"][0]["PATHS"][0]["RRDS"][0]["VALUE"];
 	$GLOBALS["netmrg"]["fileroot"]    = $xmlconfig["NETMRG"][0]["PATHS"][0]["WEBFILEROOT"][0]["VALUE"];
+	$GLOBALS["netmrg"]["locale"]      = $xmlconfig["NETMRG"][0]["PATHS"][0]["LOCALE"][0]["VALUE"];
+
+	// RRDTool Config
+	$GLOBALS["netmrg"]["rrdtool_version"] = $xmlconfig["NETMRG"][0]["RRDTOOL"][0]["VERSION"][0]["VALUE"];
+	if (empty($GLOBALS["netmrg"]["rrdtool_version"])) { $GLOBALS["netmrg"]["rrdtool_version"] = "1.0"; }
 
 } // end GetXMLConfig();
 
@@ -1335,4 +1411,4 @@ function PrereqsMet()
 	
 	return $errors;
 } // end PrereqsMet();
-?>
+?>
\ No newline at end of file
